require 'configuration'
require 'test/unit'
require 'test-util.rb'
require 'path-cache.rb'

class DeclarativeTests < Test::Unit::TestCase
  include PageAssertions
  include ServerControl

  def initialize(*args)
    super
  end

  def setup
    @browser = Browser.new
    start_server_on(TEST_HOST)
    @cache = PathCache.for_this_test(__FILE__)
  end

  def teardown
    stop_server
  end
  
  def as_our_story_begins(&block)
    @browser.reset
    @browser.go(TEST_HOST_ROOT)
    if @cache.has_path?
      @cache.replay_path
      @browser.refresh
    else
      configuration = Configuration.new(@browser, &block)
      configuration.establish
      @cache.remember_path
    end
  end

  def test_cannot_append_to_a_nominal_audit
    as_our_story_begins {
      we_have_an_audit_record_with(:variance => 'nominal')
      we_are_at(:case_display_page)
    }

    assert_page_title_matches(/Case \d+/)
    assert_page_has_no_action(:add_audit)
  end

end


