require 'pp'
require 'uri'

TEST_HOST="http://localhost:8080"
TEST_HOST_ROOT = TEST_HOST+'/'

module PageAssertions
  require 'rexml/document'
  include REXML

  def assert_page_has_no_action(action)
    page = @browser.current_page
    assert_equal(nil, XPath.first(page, "//form[@name='#{action}']"))
  end

  def assert_page_title_matches(regexp)
    assert_match(regexp, XPath.first(@browser.current_page, '//title').text)
  end
end


module Test
  module Unit
    class TestCase
      def method_missing(symbol, *args)
        @browser.send(symbol, *args)
      end
    end
  end
end
        
module ServerControl
  def start_server_on(host)
    @server_pid = Process.fork {
      require 'server'
      require 'app'
      AppWebInterface.new(App.new)
    }
    await_server_at(host)
  end

  def await_server_at(host_uri)
    uri = URI.parse(host_uri)
    host, port = uri.host, uri.port
    while true
      begin
        Net::HTTP.start(host, port) { | http |
          response = http.get("/ping")
          raise "try again" unless response.is_a?(Net::HTTPOK)
        }
      rescue
        sleep 0.1
      else
        break
      end
    end
  end

  def stop_server
    Process.kill("INT", @server_pid)
    Process.wait(@server_pid)
  end
end
